# Bash Completion

To install the completion, add `. /path/to/bash_completion.d/pwn`to your e.g. `~/.bash_profile`.

The `./install.sh` script attempts to do this for you automatically.

### Shellcraft Autocomplete

The legacy autocompletion for `pwn shellcraft` is also available at `./shellcraft`.  

It is unsupported, and slow (runs `pwn shellcraft -l` every time your shell starts).

